---
author:
  - name: Sharon Patrick
    affiliation: West Virginia Clinical and Translational Science Institute
    affiliation-url: https://www.wvctsi.org/
    email: patricks@hsc.wvu.edu
    orcid: 0000-0001-6535-2013
    attributes:
      corresponding: true

  - name: Jonathan Freixas Emery
    affiliation: University of Vermont
    affiliation-url: https://www.uvm.edu/biostatistics
    email: jonathan.f.emery@uvm.edu
    orcid: 0000-0002-3353-3570

  - name: Suzanne McCahan
    affiliation: Nemours Children's Health
    affiliation-url: https://www.nemours.org/pediatric-research/labservices/core/biomedical-research-informatics.html
    # email: suzanne.mccahan@nemours.org
    # orcid:

  - name: Mary Helen Mays
    affiliation: Universidad de Puerto Rico
    affiliation-url: https://alliance.rcm.upr.edu/cores/biomedical-informatics-core
    # email:
    # orcid:
---

# Onboarding, Enclave Access, N3C Team Science {#sec-onboarding}

**Chapter Leads**: Sharon Patrick, Suzanne McCahan, Jonathan Emery

:::{.callout-note}
This chapter is being drafted in Google Docs at
<https://drive.google.com/drive/u/0/folders/1zOGR2rGGgr1lxP8mV5XmtkuxEZI_R7II>

See a draft of the chapter outline at
<https://docs.google.com/document/d/1ttUKgwVcIZHM87elrlUNV6Qi9thzOwKBg8GegKObEtg/>
:::

:::{.callout-warning}
At this point, any edits to this chapter should be made in Google Docs.  The current Markdown is for testing only.  It is NOT the source of truth (yet).
:::

The N3C has an extensive secure onboarding process due to the sensitivity of the data within the enclave.  There are several steps that need to be completed in order for a researcher or N3C user to gain access to the enclave.

## Researcher Eligibility

Citizen scientists, researchers from foreign institutions and researchers from U.S.-based institutions are all eligible to have access to the N3C Data Enclave.  Everyone with an N3C Data Enclave account has access to the tools and public datasets that are available in the Enclave.

There are several levels of Electronic Health Record (EHR) data that are available within the N3C Data Enclave. (For more information about the levels of data, see the section 'Description of Levels 1, 2, 3' in the 'Getting & Managing Data Access' chapter.  LINK NEEDS TO BE ADDED HERE)

Citizen scientists are only eligible to access synthetic data (Level 1).  This data is artificial but statistically-comparable to, and computationally derived from, the original EHR data.

Researchers from foreign institutions are eligible to access synthetic data (Level 1) and patient data that has been deidentified by removal of protected health information (PHI) (Level 2).  (PHI includes 18 elements defined by the Health Insurance Portability and Accountability Act (HIPAA).)

Researchers from U.S.-based institutions are eligible to access synthetic data (Level 1), deidentified patient data (Level 2) and patient data that includes dates of service and patient zip code (Level 3).  (The latter data set is referred to as a limited dataset because it contains only 2 or the 18 PHI elements.)

## Registration

### ORCiD; InCommon vs Login.gov

### NIH IT security training

### Human Subjects Training

Due to the secure nature of the data that is available in the N3C Enclave registration of users is key.  There are two options in which users can log in and create an account, InCOmmon or Login.gov.  The InCommon pathway is available to select institutions that participate in that identity management service. You can clock of the link to confirm if your organization participates.   If your institution does not participate with InCOmmon, you will need to create a login.gov account.  Use the link to Login.gov and complete the required fields to create an account.  Once you know which pathway you will use to create an enclave account there are other security measures that are put in place, you will need to have a ORCiD, complete NIH security Trainingn, and also human subjects tratining.

ORCiD, which stands for Open Researcher and Contributor ID, is a unique identifier free of charge to researchers.

The N3C Data enclave is hosted by National Center for Advancing Translational Sciences and all researchers must complete the "Informational Securty, Counterintelligence, Privacy Awareness, Records Management Refresher, Emergency Prepardeness Refresher" course.  The course can be accessed at [https://irtsectraining.nih.gov/public.aspx](https://irtsectraining.nih.gov/public.aspx).  The course take approximately 60-90 minutes to complete and you should print your certificate of completion.  Users need to complete Human Subjects training that aligns with their institution's guidelines.  You will need to provide the date of completion as part of enclave creation.

Overall, users will need to confirm if they use the InCOmmon or Login.gov pathway, register for an ORCiD, have completed NIH Security Training, and completed institution human subjects training.

## Data Use Agreements

The data use agreement (DUA) establishes the permitted uses of the data in the N3C Data Enclave.  By signing the agreement, an institutional official is assuring that users from their institution will abide by the terms defined in the agreement.

A DUA must be executed by National Center for Advancing Translational Science (NCATS) and a research institution.  The DUA must be signed by authorized institutional officials who have the authority to bind all users at their institution to the terms of the DUA.  (A citizen scientist who is not affiliated with an institution must execute a data use agreement with NCATS.)  A DUA will be in effect for five years from the DUA Effective Date.

Every individual who has access to the N3C Data Enclave must be covered by a DUA.  This DUA must be in place before an account for the N3C Enclave is requested.  If your institution has an active DUA, there is no additional action required with regards to the DUA.  A list of institutions with DUAs in place can be found at List of DUA Signatories: (<https://covid.cd2h.org/duas>).

The Institutional Data Use Agreement form is available at:

<https://ncats.nih.gov/files/NCATS_N3C_Data_Use_Agreement.pdf>

For more information see:

<https://ncats.nih.gov/n3c/resources/data-access>

## Enclave Access

## Research Project Teams

### Project Lead vs COllaborations

### Common roles and expectations (PIs, PMs, SMEs, Analysts, ...)

#### Expertise needed

## Domain Teams

The N3C Data enclave is built for multi-site collaboration, and aims to bring together researchers of different backgrounds with similar questions using domain teams. Because N3C is multi-site, it can be difficult to collaborate with researchers of different backgrounds from different sites. Domain Teams exist to alleviate this difficulty. Some collaboration examples could be collecting pilot data for grant submission, sharing methodology and cohort logic, or learning how to use tools for large-scale data like machine learning.

For example, let's say your institution just signed the DUA and you have some questions about the relationship between rurality and COVID treatments. You can look at the list of domain teams to see rural health. Then you can get in contact and go to the next upcoming meeting. At the meeting you can find out whether your questions are already part of an existing project within the domain team, or if a new project should be created.

If you don't see your type of questions belonging to any existing domain teams you can create a new one here:

<https://n3c-help.atlassian.net/servicedesk/customer/portal/2/group/3/create/58>

See here for a list of existing domain teams:

<https://covid.cd2h.org/domain-teams>

## Browsing Researchers/Projects/Institutions

### Object Explorer, Public Dashboard

Once you have an enclave account you can log in and use the object explorer to browse researchers and research projects.  The object explorer can be found on the left hand side of your view on the enclave homepage.  Click on Object Explorer and there are several object-type groups, to search researchers and projects, click on N3C Admin, from there are you can search Data Use Requests, N3C Researchers, and Research Projects.  If you are looking for a particular N3C researcher, you can click on that box and in the search bar type in their name and hit enter.  A new box will be displayed and you can clock on that researcher's name and from there you can see the research projects that are lead of or a collabotaro on.  You can go back to the Object Explorer, object type groups, click N3C Admin again, and search research projects by clicking that box.  Using the search bar at the top of the page you can search by key word.  Type in the key word and click enter and a results box will be displayed.  You can view all results to find the project in which you are interested in joining.  From that screen, you can select the title of the project that you are interested in joining or reading about.  There is a public-facing version of searching projects in addition to using the enclave as a search method.  Users can search [https://covid.cd2h.org/projects](https://covid.cd2h.org/projects) or [https://covid.cd2h.org/dashboard/exploration#projects](https://covid.cd2h.org/dashboard/exploration#projects) and search for title, lead investigator name and also the institution.  There are many features that are available to search using the public-facing dashboard.  There are four categories of.
